==> sui-login-password-reset-1.24.0.tgz: package/lib/components/Form/PasswordResetForm.js <==
import AtomButton, {
// atomButtonDesigns,
atomButtonShapes, atomButtonSizes } from '@s-ui/react-atom-button';
import MoleculeInputField from '@s-ui/react-molecule-input-field';
import { BASE_CLASS } from '../../config.js';
import usePasswordResetFormState from '../../hooks/components/usePasswordResetFormState.js';
import useDomain from '../../hooks/useDomain.js';
import useI18n from '../../hooks/useI18n.js';
import Notification from '../Info/Notification.js';
import ResendText from '../Info/ResendText.js';
import LoginButton from '../Input/LoginButton.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var PasswordResetForm = function PasswordResetForm() {
  var _usePasswordResetForm = usePasswordResetFormState(),
    _usePasswordResetForm2 = _usePasswordResetForm.state,
    email = _usePasswordResetForm2.email,
    isLoading = _usePasswordResetForm2.isLoading,
    errorText = _usePasswordResetForm2.errorText,
    notification = _usePasswordResetForm2.notification,
    setEmail = _usePasswordResetForm.setEmail,
    setNotification = _usePasswordResetForm.setNotification,
    setIsLoading = _usePasswordResetForm.setIsLoading,
    setErrorText = _usePasswordResetForm.setErrorText;
  var i18n = useI18n();
  var domain = useDomain();
  var checkIfInputIsEmpty = function checkIfInputIsEmpty(value) {
    var isEmpty = value.length === 0;
    isEmpty ? setErrorText(i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.ERRORS.EMPTY_EMAIL')) : setErrorText('');
    return isEmpty;
  };
  var handleChange = function handleChange(e) {
    var _e$target = e == null ? void 0 : e.target,
      value = _e$target.value;
    setEmail(value);
    checkIfInputIsEmpty(value);
  };
  var executeResetPasswordUseCase = function executeResetPasswordUseCase(_ref) {
    var onSuccessText = _ref.onSuccessText;
    domain.get('reset_password_use_case').execute({
      email: email
    }).then(function (_ref2) {
      var error = _ref2[0];
      if (error) {
        setNotification({
          text: i18n.t('LOGIN_CROSS.PASSWORD_RESET.ERRORS.GENERIC_ERROR'),
          isError: true
        });
        return;
      }
      setNotification({
        text: onSuccessText,
        isError: false
      });
    });
  };
  var handleSubmit = function handleSubmit() {
    setIsLoading(true);
    executeResetPasswordUseCase({
      onSuccessText: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.SUCCESS.EMAIL_SENDED', {
        email: email
      })
    });
  };
  var handleResend = function handleResend() {
    executeResetPasswordUseCase({
      onSuccessText: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.SUCCESS.EMAIL_RESEND', {
        email: email
      })
    });
  };
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [notification.text ? /*#__PURE__*/_jsxs(_Fragment, {
      children: [/*#__PURE__*/_jsx(Notification, {
        notificationText: notification.text,
        isError: notification.isError
      }), /*#__PURE__*/_jsx(ResendText, {
        handleResend: handleResend
      })]
    }) : null, !notification.text ? /*#__PURE__*/_jsx("div", {
      className: BASE_CLASS + "-formInput",
      children: /*#__PURE__*/_jsx(MoleculeInputField, {
        errorText: errorText,
        id: "email",
        label: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.EMAIL_LABEL'),
        name: "email",
        onChange: handleChange,
        placeholder: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.EMAIL_PLACEHOLDER'),
        size: "l",
        type: "text",
        value: email
      })
    }) : null, /*#__PURE__*/_jsxs("div", {
      className: BASE_CLASS + "-formButtons",
      children: [!notification.text ? /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-formButton",
        children: /*#__PURE__*/_jsx(AtomButton
        // disabled={} // TODO
        , {
          fullWidth: true,
          isLoading: isLoading // TODO
          ,
          onClick: handleSubmit // TODO
          ,
          shape: atomButtonShapes.CIRCULAR,
          size: atomButtonSizes.LARGE,
          children: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.SUBMIT_BUTTON')
        })
      }) : null, /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-formButton",
        children: /*#__PURE__*/_jsx(LoginButton, {})
      })]
    })]
  });
};
PasswordResetForm.displayName = 'PasswordResetForm';
export default PasswordResetForm;

==> sui-login-password-reset-1.26.0.tgz: package/lib/components/Form/PasswordResetForm.js <==
import MoleculeInputField from '@s-ui/react-molecule-input-field';
import { BASE_CLASS } from '../../config.js';
import usePasswordResetFormState from '../../hooks/components/usePasswordResetFormState.js';
import useDomain from '../../hooks/useDomain.js';
import useI18n from '../../hooks/useI18n.js';
import Notification from '../Info/Notification.js';
import ResendText from '../Info/ResendText.js';
import LoginButton from '../Input/LoginButton.js';
import SubmitButton from '../Input/SubmitButton.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var PasswordResetForm = function PasswordResetForm() {
  var _usePasswordResetForm = usePasswordResetFormState(),
    _usePasswordResetForm2 = _usePasswordResetForm.state,
    email = _usePasswordResetForm2.email,
    isLoading = _usePasswordResetForm2.isLoading,
    errorText = _usePasswordResetForm2.errorText,
    notification = _usePasswordResetForm2.notification,
    setEmail = _usePasswordResetForm.setEmail,
    setNotification = _usePasswordResetForm.setNotification,
    setIsLoading = _usePasswordResetForm.setIsLoading,
    setErrorText = _usePasswordResetForm.setErrorText;
  var i18n = useI18n();
  var domain = useDomain();
  var checkIfInputIsEmpty = function checkIfInputIsEmpty(value) {
    var isEmpty = value.length === 0;
    isEmpty ? setErrorText(i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.ERRORS.EMPTY_EMAIL')) : setErrorText('');
    return isEmpty;
  };
  var handleChange = function handleChange(e) {
    var _e$target = e == null ? void 0 : e.target,
      value = _e$target.value;
    setEmail(value);
    checkIfInputIsEmpty(value);
  };
  var executeResetPasswordUseCase = function executeResetPasswordUseCase(_ref) {
    var onSuccessText = _ref.onSuccessText;
    domain.get('reset_password_use_case').execute({
      email: email
    }).then(function (_ref2) {
      var error = _ref2[0];
      if (error) {
        setNotification({
          text: i18n.t('LOGIN_CROSS.PASSWORD_RESET.ERRORS.GENERIC_ERROR'),
          isError: true
        });
        return;
      }
      setNotification({
        text: onSuccessText,
        isError: false
      });
    });
  };
  var handleSubmit = function handleSubmit() {
    setIsLoading(true);
    executeResetPasswordUseCase({
      onSuccessText: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.SUCCESS.EMAIL_SENDED', {
        email: email
      })
    });
  };
  var handleResend = function handleResend() {
    executeResetPasswordUseCase({
      onSuccessText: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.SUCCESS.EMAIL_RESEND', {
        email: email
      })
    });
  };
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [notification.text ? /*#__PURE__*/_jsxs(_Fragment, {
      children: [/*#__PURE__*/_jsx(Notification, {
        notificationText: notification.text,
        isError: notification.isError
      }), /*#__PURE__*/_jsx(ResendText, {
        handleResend: handleResend
      })]
    }) : null, !notification.text ? /*#__PURE__*/_jsx("div", {
      className: BASE_CLASS + "-formInput",
      children: /*#__PURE__*/_jsx(MoleculeInputField, {
        errorText: errorText,
        id: "email",
        label: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.EMAIL_LABEL'),
        name: "email",
        onChange: handleChange,
        placeholder: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.EMAIL_PLACEHOLDER'),
        size: "l",
        type: "text",
        value: email
      })
    }) : null, /*#__PURE__*/_jsxs("div", {
      className: BASE_CLASS + "-formButtons",
      children: [!notification.text ? /*#__PURE__*/_jsx(SubmitButton, {
        isLoading: isLoading,
        onClick: handleSubmit,
        children: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.SUBMIT_BUTTON')
      }) : null, /*#__PURE__*/_jsx(LoginButton, {})]
    })]
  });
};
PasswordResetForm.displayName = 'PasswordResetForm';
export default PasswordResetForm;
